summaryrefslogtreecommitdiff
path: root/sd
diff options
context:
space:
mode:
Diffstat (limited to 'sd')
-rwxr-xr-xsd/source/ui/view/drviews7.cxx5
1 files changed, 3 insertions, 2 deletions
diff --git a/sd/source/ui/view/drviews7.cxx b/sd/source/ui/view/drviews7.cxx
index 0386b62b64c7..1b2d4d46683e 100755
--- a/sd/source/ui/view/drviews7.cxx
+++ b/sd/source/ui/view/drviews7.cxx
@@ -1424,9 +1424,10 @@ void DrawViewShell::GetMenuState( SfxItemSet &rSet )
bFoundNoGraphicObj = sal_True;
break;
case OBJ_OLE2 :
// #i118485# Allow Line, Area and Graphic (Metafile)
bSingleGraphicSelected = nMarkCount == 1;
- bFoundMetafile = sal_True;
+ bFoundBitmap = true;
+ bFoundMetafile = true;
break;
case OBJ_GRAF :
bSingleGraphicSelected = nMarkCount == 1;
@@ -1424,9 +1424,10 @@ void DrawViewShell::GetMenuState( SfxItemSet &rSet )
break;
case OBJ_OLE2 :
- // #i118485# Allow Line, Area and Graphic (Metafile)
+ // #i118485# #i118525# Allow Line, Area and Graphic (Metafile, Bitmap)
bSingleGraphicSelected = nMarkCount == 1;